+---------------------------------+
| layout: page                    |
+---------------------------------+
| title: VectorType (llvm.core)   |
+---------------------------------+

llvm.core.VectorType
====================

Base Class
----------

-  `llvm.core.Type <llvm.core.Type.html>`_

Properties
----------

``element``
~~~~~~~~~~~

[read-only]

A `Type <llvm.core.Type.html>`_ object representing the type of the
element of the vector.

``count``
~~~~~~~~~

[read-only]

The number of elements in the vector.
